@@ -103,6 +103,10 @@ class Errors(object):
             return self._messages[key]
         return self._dict[key]
 
+    def __contains__(self, key):
+        return key in self._dict
+    has_key = __contains__
+
     def __unicode__(self):
         return u" ".join(self._messages)
 
@@ -119,7 +123,7 @@ class Errors(object):
         self.append(error)
         return self
 
-    def __getattribute__(self, name):
+    def __getattr__(self, name):
         if name in type(self).__dict__:
             return object.__getattribute__(self, name)
         raise AttributeError(name)
