@@ -33,7 +33,11 @@ def test_suite():
 
     globs = dict(
         Request=Request,
-        formapi=formapi
+        Form=formapi.Form,
+        Proxy=formapi.Proxy,
+        action=formapi.action,
+        validator=formapi.validator,
+        required=formapi.required,
         )
 
     return unittest.TestSuite([
@@ -51,7 +55,7 @@ def test_suite():
             optionflags=OPTIONFLAGS,
             globs=globs),
         doctest.DocTestSuite(
-            'repoze.formapi.marshalling',
+            'repoze.formapi.parser',
             optionflags=OPTIONFLAGS,
             globs=globs)
         ])
